var annotated =
[
    [ "CGAL", null, [
      [ "Aff_transformation_2", "classCGAL_1_1Aff__transformation__2.html", "classCGAL_1_1Aff__transformation__2" ],
      [ "Aff_transformation_3", "classCGAL_1_1Aff__transformation__3.html", "classCGAL_1_1Aff__transformation__3" ],
      [ "Ambient_dimension", "structCGAL_1_1Ambient__dimension.html", "structCGAL_1_1Ambient__dimension" ],
      [ "Bbox_2", "classCGAL_1_1Bbox__2.html", "classCGAL_1_1Bbox__2" ],
      [ "Bbox_3", "classCGAL_1_1Bbox__3.html", "classCGAL_1_1Bbox__3" ],
      [ "Cartesian", "structCGAL_1_1Cartesian.html", "structCGAL_1_1Cartesian" ],
      [ "Cartesian_converter", "classCGAL_1_1Cartesian__converter.html", "classCGAL_1_1Cartesian__converter" ],
      [ "Circle_2", "classCGAL_1_1Circle__2.html", "classCGAL_1_1Circle__2" ],
      [ "Circle_3", "classCGAL_1_1Circle__3.html", "classCGAL_1_1Circle__3" ],
      [ "Dimension_tag", "structCGAL_1_1Dimension__tag.html", "structCGAL_1_1Dimension__tag" ],
      [ "Direction_2", "classCGAL_1_1Direction__2.html", "classCGAL_1_1Direction__2" ],
      [ "Direction_3", "classCGAL_1_1Direction__3.html", "classCGAL_1_1Direction__3" ],
      [ "Dynamic_dimension_tag", "structCGAL_1_1Dynamic__dimension__tag.html", null ],
      [ "Exact_predicates_exact_constructions_kernel", "classCGAL_1_1Exact__predicates__exact__constructions__kernel.html", null ],
      [ "Exact_predicates_exact_constructions_kernel_with_kth_root", "classCGAL_1_1Exact__predicates__exact__constructions__kernel__with__kth__root.html", null ],
      [ "Exact_predicates_exact_constructions_kernel_with_root_of", "classCGAL_1_1Exact__predicates__exact__constructions__kernel__with__root__of.html", null ],
      [ "Exact_predicates_exact_constructions_kernel_with_sqrt", "classCGAL_1_1Exact__predicates__exact__constructions__kernel__with__sqrt.html", null ],
      [ "Exact_predicates_inexact_constructions_kernel", "classCGAL_1_1Exact__predicates__inexact__constructions__kernel.html", null ],
      [ "Feature_dimension", "structCGAL_1_1Feature__dimension.html", "structCGAL_1_1Feature__dimension" ],
      [ "Filtered_kernel", "structCGAL_1_1Filtered__kernel.html", "structCGAL_1_1Filtered__kernel" ],
      [ "Filtered_kernel_adaptor", "structCGAL_1_1Filtered__kernel__adaptor.html", null ],
      [ "Filtered_predicate", "classCGAL_1_1Filtered__predicate.html", "classCGAL_1_1Filtered__predicate" ],
      [ "Homogeneous", "structCGAL_1_1Homogeneous.html", "structCGAL_1_1Homogeneous" ],
      [ "Homogeneous_converter", "classCGAL_1_1Homogeneous__converter.html", "classCGAL_1_1Homogeneous__converter" ],
      [ "Identity_transformation", "classCGAL_1_1Identity__transformation.html", null ],
      [ "Iso_cuboid_3", "classCGAL_1_1Iso__cuboid__3.html", "classCGAL_1_1Iso__cuboid__3" ],
      [ "Iso_rectangle_2", "classCGAL_1_1Iso__rectangle__2.html", "classCGAL_1_1Iso__rectangle__2" ],
      [ "Kernel_traits", "structCGAL_1_1Kernel__traits.html", "structCGAL_1_1Kernel__traits" ],
      [ "Line_2", "classCGAL_1_1Line__2.html", "classCGAL_1_1Line__2" ],
      [ "Line_3", "classCGAL_1_1Line__3.html", "classCGAL_1_1Line__3" ],
      [ "Null_vector", "classCGAL_1_1Null__vector.html", null ],
      [ "Origin", "classCGAL_1_1Origin.html", null ],
      [ "Plane_3", "classCGAL_1_1Plane__3.html", "classCGAL_1_1Plane__3" ],
      [ "Point_2", "classCGAL_1_1Point__2.html", "classCGAL_1_1Point__2" ],
      [ "Point_3", "classCGAL_1_1Point__3.html", "classCGAL_1_1Point__3" ],
      [ "Projection_traits_3", "classCGAL_1_1Projection__traits__3.html", "classCGAL_1_1Projection__traits__3" ],
      [ "Projection_traits_xy_3", "classCGAL_1_1Projection__traits__xy__3.html", "classCGAL_1_1Projection__traits__xy__3" ],
      [ "Projection_traits_xz_3", "classCGAL_1_1Projection__traits__xz__3.html", null ],
      [ "Projection_traits_yz_3", "classCGAL_1_1Projection__traits__yz__3.html", null ],
      [ "Ray_2", "classCGAL_1_1Ray__2.html", "classCGAL_1_1Ray__2" ],
      [ "Ray_3", "classCGAL_1_1Ray__3.html", "classCGAL_1_1Ray__3" ],
      [ "Reflection", "classCGAL_1_1Reflection.html", null ],
      [ "Rotation", "classCGAL_1_1Rotation.html", null ],
      [ "Scaling", "classCGAL_1_1Scaling.html", null ],
      [ "Segment_2", "classCGAL_1_1Segment__2.html", "classCGAL_1_1Segment__2" ],
      [ "Segment_3", "classCGAL_1_1Segment__3.html", "classCGAL_1_1Segment__3" ],
      [ "Simple_cartesian", "structCGAL_1_1Simple__cartesian.html", "structCGAL_1_1Simple__cartesian" ],
      [ "Simple_homogeneous", "structCGAL_1_1Simple__homogeneous.html", "structCGAL_1_1Simple__homogeneous" ],
      [ "Sphere_3", "classCGAL_1_1Sphere__3.html", "classCGAL_1_1Sphere__3" ],
      [ "Tetrahedron_3", "classCGAL_1_1Tetrahedron__3.html", "classCGAL_1_1Tetrahedron__3" ],
      [ "Translation", "classCGAL_1_1Translation.html", null ],
      [ "Triangle_2", "classCGAL_1_1Triangle__2.html", "classCGAL_1_1Triangle__2" ],
      [ "Triangle_3", "classCGAL_1_1Triangle__3.html", "classCGAL_1_1Triangle__3" ],
      [ "Vector_2", "classCGAL_1_1Vector__2.html", "classCGAL_1_1Vector__2" ],
      [ "Vector_3", "classCGAL_1_1Vector__3.html", "classCGAL_1_1Vector__3" ],
      [ "Weighted_point_2", "classCGAL_1_1Weighted__point__2.html", "classCGAL_1_1Weighted__point__2" ],
      [ "Weighted_point_3", "classCGAL_1_1Weighted__point__3.html", "classCGAL_1_1Weighted__point__3" ]
    ] ],
    [ "Kernel", "namespaceKernel.html", [
      [ "Angle_2", "classKernel_1_1Angle__2.html", "classKernel_1_1Angle__2" ],
      [ "Angle_3", "classKernel_1_1Angle__3.html", "classKernel_1_1Angle__3" ],
      [ "AreOrderedAlongLine_2", "classKernel_1_1AreOrderedAlongLine__2.html", "classKernel_1_1AreOrderedAlongLine__2" ],
      [ "AreOrderedAlongLine_3", "classKernel_1_1AreOrderedAlongLine__3.html", "classKernel_1_1AreOrderedAlongLine__3" ],
      [ "AreParallel_2", "classKernel_1_1AreParallel__2.html", "classKernel_1_1AreParallel__2" ],
      [ "AreParallel_3", "classKernel_1_1AreParallel__3.html", "classKernel_1_1AreParallel__3" ],
      [ "AreStrictlyOrderedAlongLine_2", "classKernel_1_1AreStrictlyOrderedAlongLine__2.html", "classKernel_1_1AreStrictlyOrderedAlongLine__2" ],
      [ "AreStrictlyOrderedAlongLine_3", "classKernel_1_1AreStrictlyOrderedAlongLine__3.html", "classKernel_1_1AreStrictlyOrderedAlongLine__3" ],
      [ "Assign_2", "classKernel_1_1Assign__2.html", "classKernel_1_1Assign__2" ],
      [ "Assign_3", "classKernel_1_1Assign__3.html", "classKernel_1_1Assign__3" ],
      [ "BoundedSide_2", "classKernel_1_1BoundedSide__2.html", "classKernel_1_1BoundedSide__2" ],
      [ "BoundedSide_3", "classKernel_1_1BoundedSide__3.html", "classKernel_1_1BoundedSide__3" ],
      [ "CartesianConstIterator_2", "classKernel_1_1CartesianConstIterator__2.html", null ],
      [ "CartesianConstIterator_3", "classKernel_1_1CartesianConstIterator__3.html", null ],
      [ "Circle_2", "classKernel_1_1Circle__2.html", null ],
      [ "Circle_3", "classKernel_1_1Circle__3.html", null ],
      [ "Collinear_2", "classKernel_1_1Collinear__2.html", "classKernel_1_1Collinear__2" ],
      [ "Collinear_3", "classKernel_1_1Collinear__3.html", "classKernel_1_1Collinear__3" ],
      [ "CollinearAreOrderedAlongLine_2", "classKernel_1_1CollinearAreOrderedAlongLine__2.html", "classKernel_1_1CollinearAreOrderedAlongLine__2" ],
      [ "CollinearAreOrderedAlongLine_3", "classKernel_1_1CollinearAreOrderedAlongLine__3.html", "classKernel_1_1CollinearAreOrderedAlongLine__3" ],
      [ "CollinearAreStrictlyOrderedAlongLine_2", "classKernel_1_1CollinearAreStrictlyOrderedAlongLine__2.html", "classKernel_1_1CollinearAreStrictlyOrderedAlongLine__2" ],
      [ "CollinearAreStrictlyOrderedAlongLine_3", "classKernel_1_1CollinearAreStrictlyOrderedAlongLine__3.html", "classKernel_1_1CollinearAreStrictlyOrderedAlongLine__3" ],
      [ "CollinearHasOn_2", "classKernel_1_1CollinearHasOn__2.html", "classKernel_1_1CollinearHasOn__2" ],
      [ "CompareAngle_3", "classKernel_1_1CompareAngle__3.html", "classKernel_1_1CompareAngle__3" ],
      [ "CompareAngleWithXAxis_2", "classKernel_1_1CompareAngleWithXAxis__2.html", "classKernel_1_1CompareAngleWithXAxis__2" ],
      [ "CompareDihedralAngle_3", "classKernel_1_1CompareDihedralAngle__3.html", "classKernel_1_1CompareDihedralAngle__3" ],
      [ "CompareDistance_2", "classKernel_1_1CompareDistance__2.html", "classKernel_1_1CompareDistance__2" ],
      [ "CompareDistance_3", "classKernel_1_1CompareDistance__3.html", "classKernel_1_1CompareDistance__3" ],
      [ "ComparePowerDistance_2", "classKernel_1_1ComparePowerDistance__2.html", "classKernel_1_1ComparePowerDistance__2" ],
      [ "ComparePowerDistance_3", "classKernel_1_1ComparePowerDistance__3.html", "classKernel_1_1ComparePowerDistance__3" ],
      [ "CompareSignedDistanceToLine_2", "classKernel_1_1CompareSignedDistanceToLine__2.html", "classKernel_1_1CompareSignedDistanceToLine__2" ],
      [ "CompareSlope_2", "classKernel_1_1CompareSlope__2.html", "classKernel_1_1CompareSlope__2" ],
      [ "CompareSlope_3", "classKernel_1_1CompareSlope__3.html", "classKernel_1_1CompareSlope__3" ],
      [ "CompareSquaredDistance_2", "classKernel_1_1CompareSquaredDistance__2.html", "classKernel_1_1CompareSquaredDistance__2" ],
      [ "CompareSquaredDistance_3", "classKernel_1_1CompareSquaredDistance__3.html", "classKernel_1_1CompareSquaredDistance__3" ],
      [ "CompareSquaredRadius_3", "classKernel_1_1CompareSquaredRadius__3.html", "classKernel_1_1CompareSquaredRadius__3" ],
      [ "CompareWeightedSquaredRadius_3", "classKernel_1_1CompareWeightedSquaredRadius__3.html", "classKernel_1_1CompareWeightedSquaredRadius__3" ],
      [ "CompareX_2", "classKernel_1_1CompareX__2.html", "classKernel_1_1CompareX__2" ],
      [ "CompareX_3", "classKernel_1_1CompareX__3.html", "classKernel_1_1CompareX__3" ],
      [ "CompareXAtY_2", "classKernel_1_1CompareXAtY__2.html", "classKernel_1_1CompareXAtY__2" ],
      [ "CompareXY_2", "classKernel_1_1CompareXY__2.html", "classKernel_1_1CompareXY__2" ],
      [ "CompareXY_3", "classKernel_1_1CompareXY__3.html", "classKernel_1_1CompareXY__3" ],
      [ "CompareXYZ_3", "classKernel_1_1CompareXYZ__3.html", "classKernel_1_1CompareXYZ__3" ],
      [ "CompareY_2", "classKernel_1_1CompareY__2.html", "classKernel_1_1CompareY__2" ],
      [ "CompareY_3", "classKernel_1_1CompareY__3.html", "classKernel_1_1CompareY__3" ],
      [ "CompareYAtX_2", "classKernel_1_1CompareYAtX__2.html", "classKernel_1_1CompareYAtX__2" ],
      [ "CompareYX_2", "classKernel_1_1CompareYX__2.html", "classKernel_1_1CompareYX__2" ],
      [ "CompareZ_3", "classKernel_1_1CompareZ__3.html", "classKernel_1_1CompareZ__3" ],
      [ "ComputeA_2", "classKernel_1_1ComputeA__2.html", "classKernel_1_1ComputeA__2" ],
      [ "ComputeA_3", "classKernel_1_1ComputeA__3.html", "classKernel_1_1ComputeA__3" ],
      [ "ComputeApproximateAngle_3", "classKernel_1_1ComputeApproximateAngle__3.html", "classKernel_1_1ComputeApproximateAngle__3" ],
      [ "ComputeApproximateArea_3", "classKernel_1_1ComputeApproximateArea__3.html", "classKernel_1_1ComputeApproximateArea__3" ],
      [ "ComputeApproximateDihedralAngle_3", "classKernel_1_1ComputeApproximateDihedralAngle__3.html", "classKernel_1_1ComputeApproximateDihedralAngle__3" ],
      [ "ComputeApproximateSquaredLength_3", "classKernel_1_1ComputeApproximateSquaredLength__3.html", "classKernel_1_1ComputeApproximateSquaredLength__3" ],
      [ "ComputeArea_2", "classKernel_1_1ComputeArea__2.html", "classKernel_1_1ComputeArea__2" ],
      [ "ComputeArea_3", "classKernel_1_1ComputeArea__3.html", "classKernel_1_1ComputeArea__3" ],
      [ "ComputeAreaDividedByPi_3", "classKernel_1_1ComputeAreaDividedByPi__3.html", "classKernel_1_1ComputeAreaDividedByPi__3" ],
      [ "ComputeB_2", "classKernel_1_1ComputeB__2.html", "classKernel_1_1ComputeB__2" ],
      [ "ComputeB_3", "classKernel_1_1ComputeB__3.html", "classKernel_1_1ComputeB__3" ],
      [ "ComputeC_2", "classKernel_1_1ComputeC__2.html", "classKernel_1_1ComputeC__2" ],
      [ "ComputeC_3", "classKernel_1_1ComputeC__3.html", "classKernel_1_1ComputeC__3" ],
      [ "ComputeD_3", "classKernel_1_1ComputeD__3.html", "classKernel_1_1ComputeD__3" ],
      [ "ComputeDeterminant_2", "classKernel_1_1ComputeDeterminant__2.html", "classKernel_1_1ComputeDeterminant__2" ],
      [ "ComputeDeterminant_3", "classKernel_1_1ComputeDeterminant__3.html", "classKernel_1_1ComputeDeterminant__3" ],
      [ "ComputeDx_2", "classKernel_1_1ComputeDx__2.html", "classKernel_1_1ComputeDx__2" ],
      [ "ComputeDx_3", "classKernel_1_1ComputeDx__3.html", "classKernel_1_1ComputeDx__3" ],
      [ "ComputeDy_2", "classKernel_1_1ComputeDy__2.html", "classKernel_1_1ComputeDy__2" ],
      [ "ComputeDy_3", "classKernel_1_1ComputeDy__3.html", "classKernel_1_1ComputeDy__3" ],
      [ "ComputeDz_3", "classKernel_1_1ComputeDz__3.html", "classKernel_1_1ComputeDz__3" ],
      [ "ComputeHw_2", "classKernel_1_1ComputeHw__2.html", "classKernel_1_1ComputeHw__2" ],
      [ "ComputeHw_3", "classKernel_1_1ComputeHw__3.html", "classKernel_1_1ComputeHw__3" ],
      [ "ComputeHx_2", "classKernel_1_1ComputeHx__2.html", "classKernel_1_1ComputeHx__2" ],
      [ "ComputeHx_3", "classKernel_1_1ComputeHx__3.html", "classKernel_1_1ComputeHx__3" ],
      [ "ComputeHy_2", "classKernel_1_1ComputeHy__2.html", "classKernel_1_1ComputeHy__2" ],
      [ "ComputeHy_3", "classKernel_1_1ComputeHy__3.html", "classKernel_1_1ComputeHy__3" ],
      [ "ComputeHz_3", "classKernel_1_1ComputeHz__3.html", "classKernel_1_1ComputeHz__3" ],
      [ "ComputeLInfinityDistance_2", "classKernel_1_1ComputeLInfinityDistance__2.html", "classKernel_1_1ComputeLInfinityDistance__2" ],
      [ "ComputeLInfinityDistance_3", "classKernel_1_1ComputeLInfinityDistance__3.html", "classKernel_1_1ComputeLInfinityDistance__3" ],
      [ "ComputePowerDistanceToPowerSphere_3", "classKernel_1_1ComputePowerDistanceToPowerSphere__3.html", "classKernel_1_1ComputePowerDistanceToPowerSphere__3" ],
      [ "ComputePowerProduct_2", "classKernel_1_1ComputePowerProduct__2.html", "classKernel_1_1ComputePowerProduct__2" ],
      [ "ComputePowerProduct_3", "classKernel_1_1ComputePowerProduct__3.html", "classKernel_1_1ComputePowerProduct__3" ],
      [ "ComputeScalarProduct_2", "classKernel_1_1ComputeScalarProduct__2.html", "classKernel_1_1ComputeScalarProduct__2" ],
      [ "ComputeScalarProduct_3", "classKernel_1_1ComputeScalarProduct__3.html", "classKernel_1_1ComputeScalarProduct__3" ],
      [ "ComputeSquaredArea_3", "classKernel_1_1ComputeSquaredArea__3.html", "classKernel_1_1ComputeSquaredArea__3" ],
      [ "ComputeSquaredDistance_2", "classKernel_1_1ComputeSquaredDistance__2.html", "classKernel_1_1ComputeSquaredDistance__2" ],
      [ "ComputeSquaredDistance_3", "classKernel_1_1ComputeSquaredDistance__3.html", "classKernel_1_1ComputeSquaredDistance__3" ],
      [ "ComputeSquaredLength_2", "classKernel_1_1ComputeSquaredLength__2.html", "classKernel_1_1ComputeSquaredLength__2" ],
      [ "ComputeSquaredLength_3", "classKernel_1_1ComputeSquaredLength__3.html", "classKernel_1_1ComputeSquaredLength__3" ],
      [ "ComputeSquaredLengthDividedByPiSquare_3", "classKernel_1_1ComputeSquaredLengthDividedByPiSquare__3.html", "classKernel_1_1ComputeSquaredLengthDividedByPiSquare__3" ],
      [ "ComputeSquaredRadius_2", "classKernel_1_1ComputeSquaredRadius__2.html", "classKernel_1_1ComputeSquaredRadius__2" ],
      [ "ComputeSquaredRadius_3", "classKernel_1_1ComputeSquaredRadius__3.html", "classKernel_1_1ComputeSquaredRadius__3" ],
      [ "ComputeSquaredRadiusSmallestOrthogonalCircle_2", "classKernel_1_1ComputeSquaredRadiusSmallestOrthogonalCircle__2.html", "classKernel_1_1ComputeSquaredRadiusSmallestOrthogonalCircle__2" ],
      [ "ComputeSquaredRadiusSmallestOrthogonalSphere_3", "classKernel_1_1ComputeSquaredRadiusSmallestOrthogonalSphere__3.html", "classKernel_1_1ComputeSquaredRadiusSmallestOrthogonalSphere__3" ],
      [ "ComputeVolume_3", "classKernel_1_1ComputeVolume__3.html", "classKernel_1_1ComputeVolume__3" ],
      [ "ComputeWeight_2", "classKernel_1_1ComputeWeight__2.html", "classKernel_1_1ComputeWeight__2" ],
      [ "ComputeWeight_3", "classKernel_1_1ComputeWeight__3.html", "classKernel_1_1ComputeWeight__3" ],
      [ "ComputeX_2", "classKernel_1_1ComputeX__2.html", "classKernel_1_1ComputeX__2" ],
      [ "ComputeX_3", "classKernel_1_1ComputeX__3.html", "classKernel_1_1ComputeX__3" ],
      [ "ComputeXmax_2", "classKernel_1_1ComputeXmax__2.html", "classKernel_1_1ComputeXmax__2" ],
      [ "ComputeXmax_3", "classKernel_1_1ComputeXmax__3.html", "classKernel_1_1ComputeXmax__3" ],
      [ "ComputeXmin_2", "classKernel_1_1ComputeXmin__2.html", "classKernel_1_1ComputeXmin__2" ],
      [ "ComputeXmin_3", "classKernel_1_1ComputeXmin__3.html", "classKernel_1_1ComputeXmin__3" ],
      [ "ComputeY_2", "classKernel_1_1ComputeY__2.html", "classKernel_1_1ComputeY__2" ],
      [ "ComputeY_3", "classKernel_1_1ComputeY__3.html", "classKernel_1_1ComputeY__3" ],
      [ "ComputeYAtX_2", "classKernel_1_1ComputeYAtX__2.html", "classKernel_1_1ComputeYAtX__2" ],
      [ "ComputeYmax_2", "classKernel_1_1ComputeYmax__2.html", "classKernel_1_1ComputeYmax__2" ],
      [ "ComputeYmax_3", "classKernel_1_1ComputeYmax__3.html", "classKernel_1_1ComputeYmax__3" ],
      [ "ComputeYmin_2", "classKernel_1_1ComputeYmin__2.html", "classKernel_1_1ComputeYmin__2" ],
      [ "ComputeYmin_3", "classKernel_1_1ComputeYmin__3.html", "classKernel_1_1ComputeYmin__3" ],
      [ "ComputeZ_3", "classKernel_1_1ComputeZ__3.html", "classKernel_1_1ComputeZ__3" ],
      [ "ComputeZmax_3", "classKernel_1_1ComputeZmax__3.html", "classKernel_1_1ComputeZmax__3" ],
      [ "ComputeZmin_3", "classKernel_1_1ComputeZmin__3.html", "classKernel_1_1ComputeZmin__3" ],
      [ "ConstructBarycenter_2", "classKernel_1_1ConstructBarycenter__2.html", "classKernel_1_1ConstructBarycenter__2" ],
      [ "ConstructBarycenter_3", "classKernel_1_1ConstructBarycenter__3.html", "classKernel_1_1ConstructBarycenter__3" ],
      [ "ConstructBaseVector_3", "classKernel_1_1ConstructBaseVector__3.html", "classKernel_1_1ConstructBaseVector__3" ],
      [ "ConstructBbox_2", "classKernel_1_1ConstructBbox__2.html", "classKernel_1_1ConstructBbox__2" ],
      [ "ConstructBbox_3", "classKernel_1_1ConstructBbox__3.html", "classKernel_1_1ConstructBbox__3" ],
      [ "ConstructBisector_2", "classKernel_1_1ConstructBisector__2.html", "classKernel_1_1ConstructBisector__2" ],
      [ "ConstructBisector_3", "classKernel_1_1ConstructBisector__3.html", "classKernel_1_1ConstructBisector__3" ],
      [ "ConstructCartesianConstIterator_2", "classKernel_1_1ConstructCartesianConstIterator__2.html", "classKernel_1_1ConstructCartesianConstIterator__2" ],
      [ "ConstructCartesianConstIterator_3", "classKernel_1_1ConstructCartesianConstIterator__3.html", "classKernel_1_1ConstructCartesianConstIterator__3" ],
      [ "ConstructCenter_2", "classKernel_1_1ConstructCenter__2.html", "classKernel_1_1ConstructCenter__2" ],
      [ "ConstructCenter_3", "classKernel_1_1ConstructCenter__3.html", "classKernel_1_1ConstructCenter__3" ],
      [ "ConstructCentroid_2", "classKernel_1_1ConstructCentroid__2.html", "classKernel_1_1ConstructCentroid__2" ],
      [ "ConstructCentroid_3", "classKernel_1_1ConstructCentroid__3.html", "classKernel_1_1ConstructCentroid__3" ],
      [ "ConstructCircle_2", "classKernel_1_1ConstructCircle__2.html", "classKernel_1_1ConstructCircle__2" ],
      [ "ConstructCircle_3", "classKernel_1_1ConstructCircle__3.html", "classKernel_1_1ConstructCircle__3" ],
      [ "ConstructCircumcenter_2", "classKernel_1_1ConstructCircumcenter__2.html", "classKernel_1_1ConstructCircumcenter__2" ],
      [ "ConstructCircumcenter_3", "classKernel_1_1ConstructCircumcenter__3.html", "classKernel_1_1ConstructCircumcenter__3" ],
      [ "ConstructCrossProductVector_3", "classKernel_1_1ConstructCrossProductVector__3.html", "classKernel_1_1ConstructCrossProductVector__3" ],
      [ "ConstructDifferenceOfVectors_2", "classKernel_1_1ConstructDifferenceOfVectors__2.html", "classKernel_1_1ConstructDifferenceOfVectors__2" ],
      [ "ConstructDifferenceOfVectors_3", "classKernel_1_1ConstructDifferenceOfVectors__3.html", "classKernel_1_1ConstructDifferenceOfVectors__3" ],
      [ "ConstructDirection_2", "classKernel_1_1ConstructDirection__2.html", "classKernel_1_1ConstructDirection__2" ],
      [ "ConstructDirection_3", "classKernel_1_1ConstructDirection__3.html", "classKernel_1_1ConstructDirection__3" ],
      [ "ConstructDividedVector_2", "classKernel_1_1ConstructDividedVector__2.html", "classKernel_1_1ConstructDividedVector__2" ],
      [ "ConstructDividedVector_3", "classKernel_1_1ConstructDividedVector__3.html", "classKernel_1_1ConstructDividedVector__3" ],
      [ "ConstructEquidistantLine_3", "classKernel_1_1ConstructEquidistantLine__3.html", "classKernel_1_1ConstructEquidistantLine__3" ],
      [ "ConstructIsoCuboid_3", "classKernel_1_1ConstructIsoCuboid__3.html", "classKernel_1_1ConstructIsoCuboid__3" ],
      [ "ConstructIsoRectangle_2", "classKernel_1_1ConstructIsoRectangle__2.html", "classKernel_1_1ConstructIsoRectangle__2" ],
      [ "ConstructLiftedPoint_3", "classKernel_1_1ConstructLiftedPoint__3.html", "classKernel_1_1ConstructLiftedPoint__3" ],
      [ "ConstructLine_2", "classKernel_1_1ConstructLine__2.html", "classKernel_1_1ConstructLine__2" ],
      [ "ConstructLine_3", "classKernel_1_1ConstructLine__3.html", "classKernel_1_1ConstructLine__3" ],
      [ "ConstructMaxVertex_2", "classKernel_1_1ConstructMaxVertex__2.html", "classKernel_1_1ConstructMaxVertex__2" ],
      [ "ConstructMaxVertex_3", "classKernel_1_1ConstructMaxVertex__3.html", "classKernel_1_1ConstructMaxVertex__3" ],
      [ "ConstructMidpoint_2", "classKernel_1_1ConstructMidpoint__2.html", "classKernel_1_1ConstructMidpoint__2" ],
      [ "ConstructMidpoint_3", "classKernel_1_1ConstructMidpoint__3.html", "classKernel_1_1ConstructMidpoint__3" ],
      [ "ConstructMinVertex_2", "classKernel_1_1ConstructMinVertex__2.html", "classKernel_1_1ConstructMinVertex__2" ],
      [ "ConstructMinVertex_3", "classKernel_1_1ConstructMinVertex__3.html", "classKernel_1_1ConstructMinVertex__3" ],
      [ "ConstructNormal_3", "classKernel_1_1ConstructNormal__3.html", "classKernel_1_1ConstructNormal__3" ],
      [ "ConstructObject_2", "classKernel_1_1ConstructObject__2.html", "classKernel_1_1ConstructObject__2" ],
      [ "ConstructObject_3", "classKernel_1_1ConstructObject__3.html", "classKernel_1_1ConstructObject__3" ],
      [ "ConstructOppositeCircle_2", "classKernel_1_1ConstructOppositeCircle__2.html", "classKernel_1_1ConstructOppositeCircle__2" ],
      [ "ConstructOppositeDirection_2", "classKernel_1_1ConstructOppositeDirection__2.html", "classKernel_1_1ConstructOppositeDirection__2" ],
      [ "ConstructOppositeDirection_3", "classKernel_1_1ConstructOppositeDirection__3.html", "classKernel_1_1ConstructOppositeDirection__3" ],
      [ "ConstructOppositeLine_2", "classKernel_1_1ConstructOppositeLine__2.html", "classKernel_1_1ConstructOppositeLine__2" ],
      [ "ConstructOppositeLine_3", "classKernel_1_1ConstructOppositeLine__3.html", "classKernel_1_1ConstructOppositeLine__3" ],
      [ "ConstructOppositePlane_3", "classKernel_1_1ConstructOppositePlane__3.html", "classKernel_1_1ConstructOppositePlane__3" ],
      [ "ConstructOppositeRay_2", "classKernel_1_1ConstructOppositeRay__2.html", "classKernel_1_1ConstructOppositeRay__2" ],
      [ "ConstructOppositeRay_3", "classKernel_1_1ConstructOppositeRay__3.html", "classKernel_1_1ConstructOppositeRay__3" ],
      [ "ConstructOppositeSegment_2", "classKernel_1_1ConstructOppositeSegment__2.html", "classKernel_1_1ConstructOppositeSegment__2" ],
      [ "ConstructOppositeSegment_3", "classKernel_1_1ConstructOppositeSegment__3.html", "classKernel_1_1ConstructOppositeSegment__3" ],
      [ "ConstructOppositeSphere_3", "classKernel_1_1ConstructOppositeSphere__3.html", "classKernel_1_1ConstructOppositeSphere__3" ],
      [ "ConstructOppositeTriangle_2", "classKernel_1_1ConstructOppositeTriangle__2.html", "classKernel_1_1ConstructOppositeTriangle__2" ],
      [ "ConstructOppositeVector_2", "classKernel_1_1ConstructOppositeVector__2.html", "classKernel_1_1ConstructOppositeVector__2" ],
      [ "ConstructOppositeVector_3", "classKernel_1_1ConstructOppositeVector__3.html", "classKernel_1_1ConstructOppositeVector__3" ],
      [ "ConstructOrthogonalVector_3", "classKernel_1_1ConstructOrthogonalVector__3.html", "classKernel_1_1ConstructOrthogonalVector__3" ],
      [ "ConstructPerpendicularDirection_2", "classKernel_1_1ConstructPerpendicularDirection__2.html", "classKernel_1_1ConstructPerpendicularDirection__2" ],
      [ "ConstructPerpendicularLine_2", "classKernel_1_1ConstructPerpendicularLine__2.html", "classKernel_1_1ConstructPerpendicularLine__2" ],
      [ "ConstructPerpendicularLine_3", "classKernel_1_1ConstructPerpendicularLine__3.html", "classKernel_1_1ConstructPerpendicularLine__3" ],
      [ "ConstructPerpendicularPlane_3", "classKernel_1_1ConstructPerpendicularPlane__3.html", "classKernel_1_1ConstructPerpendicularPlane__3" ],
      [ "ConstructPerpendicularVector_2", "classKernel_1_1ConstructPerpendicularVector__2.html", "classKernel_1_1ConstructPerpendicularVector__2" ],
      [ "ConstructPlane_3", "classKernel_1_1ConstructPlane__3.html", "classKernel_1_1ConstructPlane__3" ],
      [ "ConstructPoint_2", "classKernel_1_1ConstructPoint__2.html", "classKernel_1_1ConstructPoint__2" ],
      [ "ConstructPoint_3", "classKernel_1_1ConstructPoint__3.html", "classKernel_1_1ConstructPoint__3" ],
      [ "ConstructPointOn_2", "classKernel_1_1ConstructPointOn__2.html", "classKernel_1_1ConstructPointOn__2" ],
      [ "ConstructPointOn_3", "classKernel_1_1ConstructPointOn__3.html", "classKernel_1_1ConstructPointOn__3" ],
      [ "ConstructProjectedPoint_2", "classKernel_1_1ConstructProjectedPoint__2.html", "classKernel_1_1ConstructProjectedPoint__2" ],
      [ "ConstructProjectedPoint_3", "classKernel_1_1ConstructProjectedPoint__3.html", "classKernel_1_1ConstructProjectedPoint__3" ],
      [ "ConstructProjectedXYPoint_2", "classKernel_1_1ConstructProjectedXYPoint__2.html", "classKernel_1_1ConstructProjectedXYPoint__2" ],
      [ "ConstructRadicalAxis_2", "classKernel_1_1ConstructRadicalAxis__2.html", "classKernel_1_1ConstructRadicalAxis__2" ],
      [ "ConstructRadicalLine_2", "classKernel_1_1ConstructRadicalLine__2.html", "classKernel_1_1ConstructRadicalLine__2" ],
      [ "ConstructRadicalPlane_3", "classKernel_1_1ConstructRadicalPlane__3.html", "classKernel_1_1ConstructRadicalPlane__3" ],
      [ "ConstructRay_2", "classKernel_1_1ConstructRay__2.html", "classKernel_1_1ConstructRay__2" ],
      [ "ConstructRay_3", "classKernel_1_1ConstructRay__3.html", "classKernel_1_1ConstructRay__3" ],
      [ "ConstructScaledVector_2", "classKernel_1_1ConstructScaledVector__2.html", "classKernel_1_1ConstructScaledVector__2" ],
      [ "ConstructScaledVector_3", "classKernel_1_1ConstructScaledVector__3.html", "classKernel_1_1ConstructScaledVector__3" ],
      [ "ConstructSecondPoint_2", "classKernel_1_1ConstructSecondPoint__2.html", "classKernel_1_1ConstructSecondPoint__2" ],
      [ "ConstructSecondPoint_3", "classKernel_1_1ConstructSecondPoint__3.html", "classKernel_1_1ConstructSecondPoint__3" ],
      [ "ConstructSegment_2", "classKernel_1_1ConstructSegment__2.html", "classKernel_1_1ConstructSegment__2" ],
      [ "ConstructSegment_3", "classKernel_1_1ConstructSegment__3.html", "classKernel_1_1ConstructSegment__3" ],
      [ "ConstructSource_2", "classKernel_1_1ConstructSource__2.html", "classKernel_1_1ConstructSource__2" ],
      [ "ConstructSource_3", "classKernel_1_1ConstructSource__3.html", "classKernel_1_1ConstructSource__3" ],
      [ "ConstructSphere_3", "classKernel_1_1ConstructSphere__3.html", "classKernel_1_1ConstructSphere__3" ],
      [ "ConstructSumOfVectors_2", "classKernel_1_1ConstructSumOfVectors__2.html", "classKernel_1_1ConstructSumOfVectors__2" ],
      [ "ConstructSumOfVectors_3", "classKernel_1_1ConstructSumOfVectors__3.html", "classKernel_1_1ConstructSumOfVectors__3" ],
      [ "ConstructSupportingPlane_3", "classKernel_1_1ConstructSupportingPlane__3.html", "classKernel_1_1ConstructSupportingPlane__3" ],
      [ "ConstructTarget_2", "classKernel_1_1ConstructTarget__2.html", "classKernel_1_1ConstructTarget__2" ],
      [ "ConstructTarget_3", "classKernel_1_1ConstructTarget__3.html", "classKernel_1_1ConstructTarget__3" ],
      [ "ConstructTetrahedron_3", "classKernel_1_1ConstructTetrahedron__3.html", "classKernel_1_1ConstructTetrahedron__3" ],
      [ "ConstructTranslatedPoint_2", "classKernel_1_1ConstructTranslatedPoint__2.html", "classKernel_1_1ConstructTranslatedPoint__2" ],
      [ "ConstructTranslatedPoint_3", "classKernel_1_1ConstructTranslatedPoint__3.html", "classKernel_1_1ConstructTranslatedPoint__3" ],
      [ "ConstructTriangle_2", "classKernel_1_1ConstructTriangle__2.html", "classKernel_1_1ConstructTriangle__2" ],
      [ "ConstructTriangle_3", "classKernel_1_1ConstructTriangle__3.html", "classKernel_1_1ConstructTriangle__3" ],
      [ "ConstructUnitNormal_3", "classKernel_1_1ConstructUnitNormal__3.html", "classKernel_1_1ConstructUnitNormal__3" ],
      [ "ConstructVector_2", "classKernel_1_1ConstructVector__2.html", "classKernel_1_1ConstructVector__2" ],
      [ "ConstructVector_3", "classKernel_1_1ConstructVector__3.html", "classKernel_1_1ConstructVector__3" ],
      [ "ConstructVertex_2", "classKernel_1_1ConstructVertex__2.html", "classKernel_1_1ConstructVertex__2" ],
      [ "ConstructVertex_3", "classKernel_1_1ConstructVertex__3.html", "classKernel_1_1ConstructVertex__3" ],
      [ "ConstructWeightedCircumcenter_2", "classKernel_1_1ConstructWeightedCircumcenter__2.html", "classKernel_1_1ConstructWeightedCircumcenter__2" ],
      [ "ConstructWeightedCircumcenter_3", "classKernel_1_1ConstructWeightedCircumcenter__3.html", "classKernel_1_1ConstructWeightedCircumcenter__3" ],
      [ "ConstructWeightedPoint_2", "classKernel_1_1ConstructWeightedPoint__2.html", "classKernel_1_1ConstructWeightedPoint__2" ],
      [ "ConstructWeightedPoint_3", "classKernel_1_1ConstructWeightedPoint__3.html", "classKernel_1_1ConstructWeightedPoint__3" ],
      [ "Coplanar_3", "classKernel_1_1Coplanar__3.html", "classKernel_1_1Coplanar__3" ],
      [ "CoplanarOrientation_3", "classKernel_1_1CoplanarOrientation__3.html", "classKernel_1_1CoplanarOrientation__3" ],
      [ "CoplanarSideOfBoundedCircle_3", "classKernel_1_1CoplanarSideOfBoundedCircle__3.html", "classKernel_1_1CoplanarSideOfBoundedCircle__3" ],
      [ "CounterclockwiseInBetween_2", "classKernel_1_1CounterclockwiseInBetween__2.html", "classKernel_1_1CounterclockwiseInBetween__2" ],
      [ "Direction_2", "classKernel_1_1Direction__2.html", null ],
      [ "Direction_3", "classKernel_1_1Direction__3.html", null ],
      [ "DoIntersect_2", "classKernel_1_1DoIntersect__2.html", "classKernel_1_1DoIntersect__2" ],
      [ "DoIntersect_3", "classKernel_1_1DoIntersect__3.html", "classKernel_1_1DoIntersect__3" ],
      [ "Equal_2", "classKernel_1_1Equal__2.html", "classKernel_1_1Equal__2" ],
      [ "Equal_3", "classKernel_1_1Equal__3.html", "classKernel_1_1Equal__3" ],
      [ "EqualX_2", "classKernel_1_1EqualX__2.html", "classKernel_1_1EqualX__2" ],
      [ "EqualX_3", "classKernel_1_1EqualX__3.html", "classKernel_1_1EqualX__3" ],
      [ "EqualXY_3", "classKernel_1_1EqualXY__3.html", "classKernel_1_1EqualXY__3" ],
      [ "EqualY_2", "classKernel_1_1EqualY__2.html", "classKernel_1_1EqualY__2" ],
      [ "EqualY_3", "classKernel_1_1EqualY__3.html", "classKernel_1_1EqualY__3" ],
      [ "EqualZ_3", "classKernel_1_1EqualZ__3.html", "classKernel_1_1EqualZ__3" ],
      [ "HasOn_2", "classKernel_1_1HasOn__2.html", "classKernel_1_1HasOn__2" ],
      [ "HasOn_3", "classKernel_1_1HasOn__3.html", "classKernel_1_1HasOn__3" ],
      [ "HasOnBoundary_2", "classKernel_1_1HasOnBoundary__2.html", "classKernel_1_1HasOnBoundary__2" ],
      [ "HasOnBoundary_3", "classKernel_1_1HasOnBoundary__3.html", "classKernel_1_1HasOnBoundary__3" ],
      [ "HasOnBoundedSide_2", "classKernel_1_1HasOnBoundedSide__2.html", "classKernel_1_1HasOnBoundedSide__2" ],
      [ "HasOnBoundedSide_3", "classKernel_1_1HasOnBoundedSide__3.html", "classKernel_1_1HasOnBoundedSide__3" ],
      [ "HasOnNegativeSide_2", "classKernel_1_1HasOnNegativeSide__2.html", "classKernel_1_1HasOnNegativeSide__2" ],
      [ "HasOnNegativeSide_3", "classKernel_1_1HasOnNegativeSide__3.html", "classKernel_1_1HasOnNegativeSide__3" ],
      [ "HasOnPositiveSide_2", "classKernel_1_1HasOnPositiveSide__2.html", "classKernel_1_1HasOnPositiveSide__2" ],
      [ "HasOnPositiveSide_3", "classKernel_1_1HasOnPositiveSide__3.html", "classKernel_1_1HasOnPositiveSide__3" ],
      [ "HasOnUnboundedSide_2", "classKernel_1_1HasOnUnboundedSide__2.html", "classKernel_1_1HasOnUnboundedSide__2" ],
      [ "HasOnUnboundedSide_3", "classKernel_1_1HasOnUnboundedSide__3.html", "classKernel_1_1HasOnUnboundedSide__3" ],
      [ "Intersect_2", "classKernel_1_1Intersect__2.html", "classKernel_1_1Intersect__2" ],
      [ "Intersect_3", "classKernel_1_1Intersect__3.html", "classKernel_1_1Intersect__3" ],
      [ "IsDegenerate_2", "classKernel_1_1IsDegenerate__2.html", "classKernel_1_1IsDegenerate__2" ],
      [ "IsDegenerate_3", "classKernel_1_1IsDegenerate__3.html", "classKernel_1_1IsDegenerate__3" ],
      [ "IsHorizontal_2", "classKernel_1_1IsHorizontal__2.html", "classKernel_1_1IsHorizontal__2" ],
      [ "IsoCuboid_3", "classKernel_1_1IsoCuboid__3.html", null ],
      [ "IsoRectangle_2", "classKernel_1_1IsoRectangle__2.html", null ],
      [ "IsVertical_2", "classKernel_1_1IsVertical__2.html", "classKernel_1_1IsVertical__2" ],
      [ "LeftTurn_2", "classKernel_1_1LeftTurn__2.html", "classKernel_1_1LeftTurn__2" ],
      [ "LessDistanceToPoint_2", "classKernel_1_1LessDistanceToPoint__2.html", "classKernel_1_1LessDistanceToPoint__2" ],
      [ "LessDistanceToPoint_3", "classKernel_1_1LessDistanceToPoint__3.html", "classKernel_1_1LessDistanceToPoint__3" ],
      [ "LessRotateCCW_2", "classKernel_1_1LessRotateCCW__2.html", "classKernel_1_1LessRotateCCW__2" ],
      [ "LessSignedDistanceToLine_2", "classKernel_1_1LessSignedDistanceToLine__2.html", "classKernel_1_1LessSignedDistanceToLine__2" ],
      [ "LessSignedDistanceToPlane_3", "classKernel_1_1LessSignedDistanceToPlane__3.html", "classKernel_1_1LessSignedDistanceToPlane__3" ],
      [ "LessX_2", "classKernel_1_1LessX__2.html", "classKernel_1_1LessX__2" ],
      [ "LessX_3", "classKernel_1_1LessX__3.html", "classKernel_1_1LessX__3" ],
      [ "LessXY_2", "classKernel_1_1LessXY__2.html", "classKernel_1_1LessXY__2" ],
      [ "LessXY_3", "classKernel_1_1LessXY__3.html", "classKernel_1_1LessXY__3" ],
      [ "LessXYZ_3", "classKernel_1_1LessXYZ__3.html", "classKernel_1_1LessXYZ__3" ],
      [ "LessY_2", "classKernel_1_1LessY__2.html", "classKernel_1_1LessY__2" ],
      [ "LessY_3", "classKernel_1_1LessY__3.html", "classKernel_1_1LessY__3" ],
      [ "LessYX_2", "classKernel_1_1LessYX__2.html", "classKernel_1_1LessYX__2" ],
      [ "LessZ_3", "classKernel_1_1LessZ__3.html", "classKernel_1_1LessZ__3" ],
      [ "Line_2", "classKernel_1_1Line__2.html", null ],
      [ "Line_3", "classKernel_1_1Line__3.html", null ],
      [ "NonZeroCoordinateIndex_3", "classKernel_1_1NonZeroCoordinateIndex__3.html", "classKernel_1_1NonZeroCoordinateIndex__3" ],
      [ "Object_2", "classKernel_1_1Object__2.html", null ],
      [ "Object_3", "classKernel_1_1Object__3.html", null ],
      [ "Orientation_2", "classKernel_1_1Orientation__2.html", "classKernel_1_1Orientation__2" ],
      [ "Orientation_3", "classKernel_1_1Orientation__3.html", "classKernel_1_1Orientation__3" ],
      [ "OrientedSide_2", "classKernel_1_1OrientedSide__2.html", "classKernel_1_1OrientedSide__2" ],
      [ "OrientedSide_3", "classKernel_1_1OrientedSide__3.html", "classKernel_1_1OrientedSide__3" ],
      [ "Plane_3", "classKernel_1_1Plane__3.html", null ],
      [ "Point_2", "classKernel_1_1Point__2.html", null ],
      [ "Point_3", "classKernel_1_1Point__3.html", null ],
      [ "PowerSideOfBoundedPowerCircle_2", "classKernel_1_1PowerSideOfBoundedPowerCircle__2.html", "classKernel_1_1PowerSideOfBoundedPowerCircle__2" ],
      [ "PowerSideOfBoundedPowerSphere_3", "classKernel_1_1PowerSideOfBoundedPowerSphere__3.html", "classKernel_1_1PowerSideOfBoundedPowerSphere__3" ],
      [ "PowerSideOfOrientedPowerCircle_2", "classKernel_1_1PowerSideOfOrientedPowerCircle__2.html", "classKernel_1_1PowerSideOfOrientedPowerCircle__2" ],
      [ "PowerSideOfOrientedPowerSphere_3", "classKernel_1_1PowerSideOfOrientedPowerSphere__3.html", "classKernel_1_1PowerSideOfOrientedPowerSphere__3" ],
      [ "Ray_2", "classKernel_1_1Ray__2.html", null ],
      [ "Ray_3", "classKernel_1_1Ray__3.html", null ],
      [ "Segment_2", "classKernel_1_1Segment__2.html", null ],
      [ "Segment_3", "classKernel_1_1Segment__3.html", null ],
      [ "SideOfBoundedCircle_2", "classKernel_1_1SideOfBoundedCircle__2.html", "classKernel_1_1SideOfBoundedCircle__2" ],
      [ "SideOfBoundedSphere_3", "classKernel_1_1SideOfBoundedSphere__3.html", "classKernel_1_1SideOfBoundedSphere__3" ],
      [ "SideOfOrientedCircle_2", "classKernel_1_1SideOfOrientedCircle__2.html", "classKernel_1_1SideOfOrientedCircle__2" ],
      [ "SideOfOrientedSphere_3", "classKernel_1_1SideOfOrientedSphere__3.html", "classKernel_1_1SideOfOrientedSphere__3" ],
      [ "Sphere_3", "classKernel_1_1Sphere__3.html", null ],
      [ "Tetrahedron_3", "classKernel_1_1Tetrahedron__3.html", null ],
      [ "Triangle_2", "classKernel_1_1Triangle__2.html", null ],
      [ "Triangle_3", "classKernel_1_1Triangle__3.html", null ],
      [ "Vector_2", "classKernel_1_1Vector__2.html", null ],
      [ "Vector_3", "classKernel_1_1Vector__3.html", null ],
      [ "WeightedPoint_2", "classKernel_1_1WeightedPoint__2.html", null ],
      [ "WeightedPoint_3", "classKernel_1_1WeightedPoint__3.html", null ]
    ] ],
    [ "Kernel", "classKernel.html", "classKernel" ],
    [ "ProjectionTraitsGeometricTraits_3", "classProjectionTraitsGeometricTraits__3.html", null ]
];